<?php
if ( ! function_exists('wp_notify_postauthor') ) :
	function wp_notify_postauthor ( $comment_id, $comment_type='' ) {
		$comment = get_comment( $comment_id );
		$post    = get_post( $comment->comment_post_ID );
		$user    = get_userdata( $post->post_author );
		$current_user = wp_get_current_user();
		
		if ( $comment->user_id == $post->post_author ) return false; // The author moderated a comment on his own post
		
		if ( '' == $user->user_email ) return false; // If there's no email to send the comment to
		
		$comment_author_domain = @gethostbyaddr($comment->comment_author_IP);
		
		$blogname = htmlize_get_blogname();
		
		if ( empty( $comment_type ) ) $comment_type = 'comment';
		
		$email_data = array();
		
		$email_data['email_title']	 = sprintf( __('New %s on your post', 'html-emails'), $comment_type );
		$email_data['email_subtitle']  = htmlize_maybe_linkify( get_permalink( $comment->comment_post_ID ), sprintf( __('<em>%1$s</em> #%2$s'), $post->post_title, $comment->comment_post_ID ) );
		
		$email_data['email_data'] = array(
				'comment' 		=> $comment,
				'comment_type' 	=> $comment_type,
				'post'			=> $post,
				'user'			=> $user,
				'current_user' 	=> $current_user
			);
			
		$email_data['email_templates'] = array( "notify_postauthor_$comment_type.php", 'notify_postauthor.php', 'notify_comment.php' );
		
		$notify_message = htmlize_message( $email_data );
		$subject = sprintf( __('[%1$s] %2$s: "%3$s"'), $blogname, ucwords($comment_type), $post->post_title );
		$wp_email = htmlize_get_wp_email();
		
		if ( '' == $comment->comment_author ) {
			$from = "From: \"$blogname\" <$wp_email>";
			if ( '' != $comment->comment_author_email )
				$reply_to = "Reply-To: $comment->comment_author_email";
		} else {
			$from = "From: \"$comment->comment_author\" <$wp_email>";
			if ( '' != $comment->comment_author_email )
				$reply_to = "Reply-To: \"$comment->comment_author_email\" <$comment->comment_author_email>";
		}
		
		$message_headers = "$from\n";
		$message_headers .= htmlize_get_message_headers();
		
		if ( isset($reply_to) )
			$message_headers .= $reply_to . "\n";
		
		$to_email = $user->user_email;
		$notify_message = apply_filters('comment_notification_text', $notify_message, $comment_id);
		$subject = apply_filters('comment_notification_subject', $subject, $comment_id);
		$message_headers = apply_filters('comment_notification_headers', $message_headers, $comment_id);
		
		@wp_mail($to_email, $subject, $notify_message, $message_headers);
		
		return true;
	}
endif;

if ( !function_exists('wp_notify_moderator') ) :
	function wp_notify_moderator( $comment_id ) {
		global $wpdb;
		
		if( get_option( "moderation_notify" ) == 0 )
			return true;
		
		$comment = get_comment( $comment_id );
		$post = get_post( $comment->comment_post_ID );
		
		$comment_author_domain = @gethostbyaddr($comment->comment_author_IP);
		$comments_waiting = $wpdb->get_var("SELECT count(comment_ID) FROM $wpdb->comments WHERE comment_approved = '0'");
		
		$comment_type = $comment->comment_type ? $comment->comment_type : 'comment';
		
		$blogname = htmlize_get_blogname();
		
		$email_data = array();
		
		$email_data['email_title'] = sprintf( __('New %s awaiting approval'), $comment_type ) . "\r\n";
		$email_data['email_subtitle']  = htmlize_maybe_linkify( get_permalink( $comment->comment_post_ID ), sprintf( __('<em>%1$s</em> #%2$s'), $post->post_title, $comment->comment_post_ID ) );
		
		$email_data['email_data'] = array(
			'comment' 			=> $comment,
			'comment_type' 		=> $comment_type,
			'comment_moderate' 	=> true,
			'post'				=> $post
		);
		
		$email_data['email_templates'] = array( "notify_moderator_$comment_type.php", 'notify_moderator.php', 'notify_comment.php' );
		
		$notify_message = htmlize_message( $email_data );
		
		$subject = sprintf( __('[%1$s] Please moderate: "%2$s"'), $blogname, $post->post_title );
		$to_email = get_option('admin_email');
		
		$message_headers = htmlize_get_message_headers();
		
		$notify_message = apply_filters('comment_moderation_text', $notify_message, $comment_id);
		$subject = apply_filters('comment_moderation_subject', $subject, $comment_id);
		$message_headers = apply_filters('comment_moderation_headers', $message_headers);
		
		//@wp_mail($to_email, $subject, $notify_message, $message_headers);
		
		return true;
	}
endif;

/* TO BE ADDED SOON:

if ( !function_exists('wp_password_change_notification') ) :
function wp_password_change_notification(&$user) {
	// send a copy of password change notification to the admin
	// but check to see if it's the admin whose password we're changing, and skip this
	if ( $user->user_email != get_option('admin_email') ) {
		$message = sprintf(__('Password Lost and Changed for user: %s'), $user->user_login) . "\r\n";
		
		$blogname = htmlize_get_blogname();
		
		wp_mail(get_option('admin_email'), sprintf(__('[%s] Password Lost/Changed'), $blogname), $message);
	}
}
endif;

if ( !function_exists('wp_new_user_notification') ) :
function wp_new_user_notification($user_id, $plaintext_pass = '') {
	$user = new WP_User($user_id);

	$user_login = stripslashes($user->user_login);
	$user_email = stripslashes($user->user_email);
	
	$blogname = htmlize_get_blogname();

	$message  = sprintf(__('New user registration on your blog %s:'), $blogname) . "\r\n\r\n";
	$message .= sprintf(__('Username: %s'), $user_login) . "\r\n\r\n";
	$message .= sprintf(__('E-mail: %s'), $user_email) . "\r\n";

	@wp_mail(get_option('admin_email'), sprintf(__('[%s] New User Registration'), $blogname), $message);

	if ( empty($plaintext_pass) )
		return;

	$message  = sprintf(__('Username: %s'), $user_login) . "\r\n";
	$message .= sprintf(__('Password: %s'), $plaintext_pass) . "\r\n";
	$message .= wp_login_url() . "\r\n";

	wp_mail($user_email, sprintf(__('[%s] Your username and password'), $blogname), $message);

}
endif;
*/
?>